@@ -1,3 +1,5 @@
+from __future__ import annotations
+
 from typing import Dict, List, Optional, Set
 
 from kubernetes.client import (
@@ -6,6 +8,7 @@ from kubernetes.client import (
     V1Deployment,
     V1ObjectMeta,
     V1PodSpec,
+    V1StatefulSet,
 )
 from loguru import logger
 
@@ -14,27 +17,100 @@ from streams_explorer.extractors import extractor_container
 
 
 class K8sApp:
-    def __init__(self):
-        self.name = None
-        self.metadata = None
-        self.input_topics = None
-        self.output_topic = None
-        self.error_topic = None
-        self.extra_input_topics = None
-        self.extra_output_topics = None
+    def __init__(self, k8s_object):
+        self.k8s_object = k8s_object
+        self.metadata: Optional[V1ObjectMeta] = k8s_object.metadata
+        self.name: str = self.get_name()
+        self.input_topics: List[str] = []
+        self.output_topic: Optional[str] = None
+        self.error_topic: Optional[str] = None
+        self.extra_input_topics: List[str] = []
+        self.extra_output_topics: List[str] = []
         self.attributes: Dict[str, str] = {}
+        self.setup()
+
+    def setup(self):
+        self.spec = self.k8s_object.spec.template.spec
+        self._ignore_containers = self.get_ignore_containers()
+        self.container = self.get_app_container(self.spec, self._ignore_containers)
+        self.env_prefix = self.get_env_prefix(self.container)
+        self.__get_common_configuration()
+        self.__get_attributes()
 
     def to_dict(self) -> dict:
-        pass
+        return self.k8s_object.to_dict()
 
-    def get_name(self) -> Optional[str]:
-        pass
+    def get_name(self) -> str:
+        name = self.metadata.labels.get("app")
+        if not name:
+            raise TypeError(f"Name is required for {self.get_class_name()}")
+        return name
+
+    def __get_common_configuration(self):
+        for env in self.container.env:
+            name = env.name
+            if name == self._get_env_name("INPUT_TOPICS"):
+                self.input_topics = self.parse_input_topics(env.value)
+            elif name == self._get_env_name("OUTPUT_TOPIC"):
+                self.output_topic = env.value
+            elif name == self._get_env_name("ERROR_TOPIC"):
+                self.error_topic = env.value
+            elif name == self._get_env_name("EXTRA_INPUT_TOPICS"):
+                self.extra_input_topics = self.parse_extra_topics(env.value)
+            elif name == self._get_env_name("EXTRA_OUTPUT_TOPICS"):
+                self.extra_output_topics = self.parse_extra_topics(env.value)
+
+            if self.is_streams_bootstrap_app():
+                extractor_container.on_streaming_app_env_parsing(env, self.name)
+
+    def is_streams_bootstrap_app(self) -> bool:
+        if not self.input_topics and not self.output_topic:
+            return False
+        return True
+
+    def get_class_name(self) -> str:
+        return self.__class__.__name__
+
+    def _get_env_name(self, variable_name) -> str:
+        return f"{self.env_prefix}{variable_name}"
+
+    def __get_attributes(self):
+        labels = self.metadata.labels
+        labels_to_use = self.get_labels()
+
+        for key in labels_to_use:
+            value = labels.get(key)
+            if value is not None:
+                self.attributes[key] = value
+            elif self.is_streams_bootstrap_app():
+                logger.warning(
+                    f"{self.get_class_name()} {self.name} does not have a label with the name: {key}"
+                )
+
+        if (
+            self.k8s_object.spec.template.metadata
+            and self.k8s_object.spec.template.metadata.annotations
+        ):
+            annotations = self.k8s_object.spec.template.metadata.annotations
+            self.attributes.update(annotations)
 
     @staticmethod
-    def get_env_prefix(container: V1Container) -> Optional[str]:
-        for env_var in container.env:
-            if env_var.name == "ENV_PREFIX":
-                return env_var.value
+    def factory(k8s_object: object) -> K8sApp:
+        if isinstance(k8s_object, V1Deployment):
+            return K8sAppDeployment(k8s_object)
+        elif isinstance(k8s_object, V1StatefulSet):
+            return K8sAppStatefulSet(k8s_object)
+        elif isinstance(k8s_object, V1beta1CronJob):
+            return K8sAppCronJob(k8s_object)
+        else:
+            raise ValueError(k8s_object)
+
+    @staticmethod
+    def get_env_prefix(container: Optional[V1Container]) -> Optional[str]:
+        if container:
+            for env_var in container.env:
+                if env_var.name == "ENV_PREFIX":
+                    return env_var.value
         return None
 
     @staticmethod
@@ -48,12 +124,10 @@ class K8sApp:
 
     @staticmethod
     def get_ignore_containers() -> Set[str]:
-        return set(
-            [container.get("name") for container in settings.k8s.containers.ignore]
-        )
+        return {container["name"] for container in settings.k8s.containers.ignore}
 
     @staticmethod
-    def get_labels() -> Set:
+    def get_labels() -> Set[str]:
         return set(settings.k8s.labels)
 
     @staticmethod
@@ -73,22 +147,20 @@ class K8sApp:
 
 
 class K8sAppCronJob(K8sApp):
-    def __init__(self, cron_job: V1beta1CronJob):
-        super().__init__()
-        self.cron_job = cron_job
-        self.metadata: V1ObjectMeta = cron_job.metadata
-        self.name = self.get_name()
-        self.spec = cron_job.spec.job_template.spec.template.spec
-        self.container = self.get_app_container(self.spec)
-        self._env_prefix = self.get_env_prefix(self.container)
+    def __init__(self, k8s_object: V1beta1CronJob):
+        super().__init__(k8s_object)
 
+    def setup(self):
+        self.spec = self.k8s_object.spec.job_template.spec.template.spec
+        self.container = self.get_app_container(self.spec)
+        self.env_prefix = self.get_env_prefix(self.container)
         self.__get_common_configuration()
 
-    def get_name(self) -> Optional[str]:
-        return self.metadata.name
-
-    def _get_env_name(self, variable_name) -> str:
-        return f"{self._env_prefix}{variable_name}"
+    def get_name(self) -> str:
+        name = self.metadata.name
+        if not name:
+            raise TypeError(f"Name is required for {self.get_class_name()}")
+        return name
 
     def __get_common_configuration(self):
         for env in self.container.env:
@@ -102,65 +174,13 @@ class K8sAppCronJob(K8sApp):
 
 
 class K8sAppDeployment(K8sApp):
-    def __init__(self, deployment: V1Deployment):
-        super().__init__()
-        self.deployment = deployment
-        self.metadata: V1ObjectMeta = deployment.metadata
-        self.name = self.get_name()
-        self.spec = deployment.spec.template.spec
-        self._ignore_containers = self.get_ignore_containers()
-        self.container = self.get_app_container(self.spec, self._ignore_containers)
-        self._env_prefix = self.get_env_prefix(self.container)
+    def __init__(self, k8s_object: V1Deployment):
+        super().__init__(k8s_object)
 
-        self.__get_common_configuration()
-        self.__get_attributes()
 
-    def get_name(self) -> Optional[str]:
-        return self.metadata.labels.get("app")
+class K8sAppStatefulSet(K8sApp):
+    def __init__(self, k8s_object: V1StatefulSet):
+        super().__init__(k8s_object)
 
-    def __get_common_configuration(self):
-        for env in self.container.env:
-            name = env.name
-            if name == self._get_env_name("INPUT_TOPICS"):
-                self.input_topics = self.parse_input_topics(env.value)
-            elif name == self._get_env_name("OUTPUT_TOPIC"):
-                self.output_topic = env.value
-            elif name == self._get_env_name("ERROR_TOPIC"):
-                self.error_topic = env.value
-            elif name == self._get_env_name("EXTRA_INPUT_TOPICS"):
-                self.extra_input_topics = self.parse_extra_topics(env.value)
-            elif name == self._get_env_name("EXTRA_OUTPUT_TOPICS"):
-                self.extra_output_topics = self.parse_extra_topics(env.value)
-
-            extractor_container.on_streaming_app_env_parsing(env, self.name)
-
-    def __get_attributes(self):
-        labels = self.metadata.labels
-        labels_to_use = self.get_labels()
-
-        for key in labels_to_use:
-            value = labels.get(key)
-            if value is not None:
-                self.attributes[key] = value
-            elif self.is_common_streams_app():
-                logger.warning(
-                    f"Deployment {self.name} does not have a label with the name: {key}"
-                )
-
-        if (
-            self.deployment.spec.template.metadata
-            and self.deployment.spec.template.metadata.annotations
-        ):
-            annotations = self.deployment.spec.template.metadata.annotations
-            self.attributes.update(annotations)
-
-    def _get_env_name(self, variable_name) -> str:
-        return f"{self._env_prefix}{variable_name}"
-
-    def is_common_streams_app(self) -> bool:
-        if self.input_topics is None and self.output_topic is None:
-            return False
-        return True
-
-    def to_dict(self) -> dict:
-        return self.deployment.to_dict()
+    def get_service_name(self) -> str:
+        return self.k8s_object.spec.service_name
