@@ -1,11 +1,11 @@
-from typing import Dict, List, Optional
+from typing import Dict, List, Optional, Type
 
 import kubernetes
-from kubernetes.client import V1beta1CronJob, V1Deployment
+from kubernetes.client import V1beta1CronJob, V1Deployment, V1StatefulSet
 from loguru import logger
 
 from streams_explorer.core.config import settings
-from streams_explorer.core.k8s_app import K8sApp, K8sAppDeployment
+from streams_explorer.core.k8s_app import K8sApp
 from streams_explorer.core.node_info_extractor import (
     get_displayed_information_connector,
     get_displayed_information_deployment,
@@ -13,6 +13,7 @@ from streams_explorer.core.node_info_extractor import (
 from streams_explorer.core.services.dataflow_graph import DataFlowGraph, NodeTypesEnum
 from streams_explorer.core.services.kafkaconnect import KafkaConnect
 from streams_explorer.core.services.linking_services import LinkingService
+from streams_explorer.core.services.metric_providers import MetricProvider
 from streams_explorer.core.services.schemaregistry import SchemaRegistry
 from streams_explorer.extractors import extractor_container
 from streams_explorer.models.kafka_connector import KafkaConnector
@@ -27,10 +28,12 @@ class StreamsExplorer:
     context = settings.k8s.deployment.context
     namespaces = settings.k8s.deployment.namespaces
 
-    def __init__(self, linking_service: LinkingService):
+    def __init__(
+        self, linking_service: LinkingService, metric_provider: Type[MetricProvider]
+    ):
         self.applications: Dict[str, K8sApp] = {}
         self.kafka_connectors: List[KafkaConnector] = []
-        self.data_flow = DataFlowGraph()
+        self.data_flow = DataFlowGraph(metric_provider=metric_provider)
         self.linking_service = linking_service
 
     def setup(self):
@@ -126,12 +129,11 @@ class StreamsExplorer:
         self.k8s_batch_client = kubernetes.client.BatchV1beta1Api()
 
     def __retrieve_deployments(self):
-        logger.info("Retrieve deployment descriptions")
-        deployments = self.get_deployments()
-        for item in deployments:
+        items = self.get_deployments() + self.get_stateful_sets()
+        for item in items:
             try:
-                app = K8sAppDeployment(item)
-                if app.is_common_streams_app():
+                app = K8sApp.factory(item)
+                if app.is_streams_bootstrap_app():
                     self.applications[app.name] = app
             except Exception as e:
                 logger.debug(e)
@@ -145,6 +147,15 @@ class StreamsExplorer:
             ).items
         return deployments
 
+    def get_stateful_sets(self) -> List[V1StatefulSet]:
+        stateful_sets: List[V1StatefulSet] = []
+        for namespace in self.namespaces:
+            logger.info(f"List statefulsets in namespace {namespace}")
+            stateful_sets += self.k8s_app_client.list_namespaced_stateful_set(
+                namespace=namespace, watch=False
+            ).items
+        return stateful_sets
+
     def __retrieve_cron_jobs(self):
         logger.info("Retrieve cronjob descriptions")
         cron_jobs = self.get_cron_jobs()
